package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````R!8``#0```"HE0````0`!30`(``'
M`"@`'``;``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!<````7````!`````$````!````````````````````W(\`
M`-R/```%```````!``$```#<CP``W(\!`-R/`0"X`@``*`,```8```````$`
M`@```.B/``#HCP$`Z(\!`/````#P````!@````0````$````+`$``"P!```L
M`0``3````$P````$````!````%#E=&3\B0``_(D``/R)```$`0``!`$```0`
M```$````+W5S<B]L:6)E>&5C+VQD+F5L9E]S;P``!P````0````!````3F5T
M0E-$````RIH[!`````0````#````4&%8```````'````"0````4```!.971"
M4T0``&5A<FUV-FAF`````&$```!L```````````````Q````#@``````````
M````.0````\```!!`````````#```````````P```$\```!D`````````"``
M``!.````!@```!X````5`````````$0```!9````8``````````8````/0``
M`%L```!E`````````&@```!J````+P```!,```!:````1@```!8```!?````
M2`````````!+````1P```#8```!>````)@```"H`````````!P```%``````
M````#````"P```!K````70```$T````A````40```&D`````````8@``````
M```9````+@```$(````````````````````2````,P`````````*````8P``
M`"L`````````"0`````````D````.@````````!2````!0```$D````<````
M/`````````````````````````!,`````````#L```!5````9@````````!G
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!0`````````
M`````````````````````````````````````",````B`````````"D`````
M````"P```"<````H````+0``````````````#0`````````=````&P```#4`
M```:```````````````1`````````#0````R````.````!\`````````````
M``````````````````0```````````````````!#````)0``````````````
M`````!<`````````0````$4````(````````````````````/P````````!4
M``````````````!8```````````````^````5P````````!3`````````$H`
M```0``````````````!6````7````#<```!A````````````````````````
M````````````R!8````````#``L``````.2/`0```````P`1`)D`````````
M`````!(````,```````````````2````%```````````````$@```'H#``"4
M(0``"````!(`"P`<```````````````B````*P``````````````$@```$,#
M`````````````!(````Q```````````````2````BP,``)22`0``````$``5
M`#@``````````````!(```"9`P``8"P``!@````2``L`/P``````````````
M$@```%`#`````````````!(```!'```````````````2````M`,``%@W``!8
M````$@`+`(H``````````````!(```#(`P``!),!```````0`!4`3P``````
M````````$@```,`#``"4D@$``````!``%`!?```````````````2````;@``
M````````````$@```'0``````````````!(```![```````````````2````
MA0``````````````$@```(\``````````````!(```#'`P``!),!```````0
M`!4`F```````````````$@```%<"`````````````!(```">````````````
M```2````I0``````````````$@```+,``````````````!(```#$````````
M```````1````T0``````````````$@```-,#```4)```)````!(`"P#@`P``
M."0``%`````2``L`[`,``-0M``#<!@``$@`+`-\``````````````!8```#R
M```````````````2````8@,`````````````$@```/T``````````````!(`
M```&`0```),!``0````1`!4`#@$`````````````$@```!<!````````````
M`!(````Y`P`````````````2````(P$`````````````$@```"H!````````
M`````!(```#Y`P``9$,```0!```2``L`/0$`````````````$0```$\!````
M`````````!(```!?`0`````````````2````;0$`````````````$@```'(!
M`````````````!$```"!`0`````````````2````!`0``)"2`0`$````$0`4
M`)`!`````````````!(```"<`0`````````````2````L0$`````````````
M$@```+P!`````````````!(```!U`P``!),!```````0`!4`^@(`````````
M````$@```,\!`````````````!(```!'!```R!8````````2``L`W0$`````
M````````$@```.4!`````````````"(```#]`0`````````````2````"0(`
M````````````$@````X$```$DP$``````!``%0`6!```B"0``#@%```2``L`
M#P(`````````````(@```"4"`````````````!(````P`@`````````````2
M````(P0``&A$``!``0``$@`+`$$"`````````````!(````M!```E)(!````
M```0`!4`.00``,`@``!<````$@`+`$$$``!X1@``L`(``!(`"P!(`@``````
M```````2````1@0``,@6````````$@`+`$\"`````````````!(```!.!```
MG"$``'@"```2``L`6P0``'@L``!<`0``$@`+`%8"`````````````!(```!M
M!```P"D``)0````2``L`7P(`````````````$@```'`"`````````````!(`
M``#C`@`````````````2````=P(`````````````$@```'L$``!4*@``9```
M`!(`"P"&`@`````````````2````CP(`````````````$@```)4"````````
M`````!(````L`P`````````````2````F@(`````````````$@```!\#``#$
MD@$`!````!$`%0"B`@`````````````2````5P,`````````````$@```*D"
M`````````````!(```"#!```"$,``%P````2``L`L`(`````````````$@``
M`+\"`````````````!$````4`P``3)(!``0````1`!0`C`0``+`T``"H`@``
M$@`+`#8!`````````````!(```#$`@`````````````2````:0,`````````
M````$@````!L:6)P97)L+G-O`')E86QL;V,`;65M;6]V90!?7V-X85]F:6YA
M;&EZ90!R;61I<@!S=')S='(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?;'-T
M870U,`!P97)L7V9R964`7U]S=&%T-3``7V5X:70`;65M8W!Y`'!E<FQ?9&5S
M=')U8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``4&5R;%]S=E]S
M971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E
M;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`&UE;7-E=`!097)L7W-A9F5S
M>7-M86QL;V,`7U]S=&%C:U]C:&M?9W5A<F0`4&5R;%]G=E]F971C:'!V`%]?
M<W!R:6YT9E]C:&L`<F5A9`!03%]M96UO<GE?=W)A<`!097)L7W-Y<U]I;FET
M,P!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3
M`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?97)R;F\`7U]D
M97)E9VES=&5R7V9R86UE7VEN9F\`4&5R;%]M9U]S970`;6MD:7(`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`'!E<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A
M8V-E<W,`9V5T<&ED`&UE;6-H<@!V9G!R:6YT9@!097)L7V%T9F]R:U]L;V-K
M`&UE;6-M<`!097)L7W-V7W-E='!V;@!P97)L7W)U;@!L<V5E:P!O<&5N`'-P
M<FEN=&8`9V5T=6ED`'-T<FQE;@!?7W1L<U]G971?861D<@!?7W-&`'-T<F-M
M<`!L:6)M+G-O+C``;&EB8W)Y<'0N<V\N,0!S=')D=7``;&EB<'1H<F5A9"YS
M;RXQ`'!T:')E861?871F;W)K`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S
M7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!?7W-T<&-P>5]C:&L`
M871E>&ET`%]L:6)C7VEN:70`<W1R=&]K`%]?<F5A9&1I<C,P`%]E;F0`<&%R
M7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`
M;7E?<&%R7W!L`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S
M<U]S=&%R=`!X<U]I;FET`&UA:6X`7U]S=&%R=`!P87)?9FEN9'!R;V<`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H85]I;FET
M`%A37TEN=&5R;F%L<U]005)?0D]/5``O=7-R+W!K9R]L:6(O<&5R;#4O-2XS
M."XP+V5A<FUV-FAF+6YE=&)S9"UT:')E860M;75L=&DO0T]213HO=7-R+W!K
M9R]L:6(``-R/`0`7````X(\!`!<```#PD0$`%P````"2`0`7````$)(!`!<`
M```<D@$`%P```"22`0`7````-)(!`!<````\D@$`%P```$22`0`7````2)(!
M`!<```!,D@$`%P```%"2`0`7````8)(!`!<```!DD@$`%P```&R2`0`7````
M<)(!`!<```!TD@$`%P```'B2`0`7````?)(!`!<```"$D@$`%P```(B2`0`7
M````D)(!`!<```#TD0$`%0<``/R1`0`5%```!)(!`!4B```(D@$`$2<```R2
M`0`2)P``&)(!`!4R```@D@$`%38``"B2`0`5/```+)(!`!5"```PD@$`%4<`
M`#B2`0`55@``0)(!`!5F``#DD`$`%@,``.B0`0`6!```[)`!`!8%``#PD`$`
M%@<``/20`0`6"```^)`!`!8)``#\D`$`%@H```"1`0`6#```!)$!`!8.```(
MD0$`%@\```R1`0`6$```$)$!`!82```4D0$`%A8``!B1`0`6%P``')$!`!88
M```@D0$`%AD``"21`0`6&@``*)$!`!8;```LD0$`%AT``#"1`0`6'@``-)$!
M`!8?```XD0$`%B```#R1`0`6(0``0)$!`!8C``!$D0$`%B@``$B1`0`6*0``
M3)$!`!8J``!0D0$`%BP``%21`0`6+0``6)$!`!8N``!<D0$`%B\``&"1`0`6
M,```9)$!`!8S``!HD0$`%C0``&R1`0`6-0``<)$!`!8W``!TD0$`%CD``'B1
M`0`6.@``?)$!`!8[``"`D0$`%CX``(21`0`6/P``B)$!`!9!``",D0$`%D(`
M`)"1`0`60P``E)$!`!9$``"8D0$`%D<``)R1`0`62```H)$!`!9)``"DD0$`
M%DL``*B1`0`63P``K)$!`!91``"PD0$`%E0``+21`0`65P``N)$!`!98``"\
MD0$`%ED``,"1`0`66P``Q)$!`!9<``#(D0$`%ET``,R1`0`67@``T)$!`!9?
M``#4D0$`%F$``-B1`0`68@``W)$!`!9C``#@D0$`%F4``.21`0`6:0``Z)$!
M`!9J``#LD0$`%FL```3@+>4$X)_E#N"/X`CPON4X?0$``,:/XA?*C.(X_;SE
M`,:/XA?*C.(P_;SE`,:/XA?*C.(H_;SE`,:/XA?*C.(@_;SE`,:/XA?*C.(8
M_;SE`,:/XA?*C.(0_;SE`,:/XA?*C.((_;SE`,:/XA?*C.(`_;SE`,:/XA?*
MC.+X_+SE`,:/XA?*C.+P_+SE`,:/XA?*C.+H_+SE`,:/XA?*C.+@_+SE`,:/
MXA?*C.+8_+SE`,:/XA?*C.+0_+SE`,:/XA?*C.+(_+SE`,:/XA?*C.+`_+SE
M`,:/XA?*C.*X_+SE`,:/XA?*C.*P_+SE`,:/XA?*C.*H_+SE`,:/XA?*C.*@
M_+SE`,:/XA?*C.*8_+SE`,:/XA?*C.*0_+SE`,:/XA?*C.*(_+SE`,:/XA?*
MC.*`_+SE`,:/XA?*C.)X_+SE`,:/XA?*C.)P_+SE`,:/XA?*C.)H_+SE`,:/
MXA?*C.)@_+SE`,:/XA?*C.)8_+SE`,:/XA?*C.)0_+SE`,:/XA?*C.)(_+SE
M`,:/XA?*C.)`_+SE`,:/XA?*C.(X_+SE`,:/XA?*C.(P_+SE`,:/XA?*C.(H
M_+SE`,:/XA?*C.(@_+SE`,:/XA?*C.(8_+SE`,:/XA?*C.(0_+SE`,:/XA?*
MC.((_+SE`,:/XA?*C.(`_+SE`,:/XA?*C.+X^[SE`,:/XA?*C.+P^[SE`,:/
MXA?*C.+H^[SE`,:/XA?*C.+@^[SE`,:/XA?*C.+8^[SE`,:/XA?*C.+0^[SE
M`,:/XA?*C.+(^[SE`,:/XA?*C.+`^[SE`,:/XA?*C.*X^[SE`,:/XA?*C.*P
M^[SE`,:/XA?*C.*H^[SE`,:/XA?*C.*@^[SE`,:/XA?*C.*8^[SE`,:/XA?*
MC.*0^[SE`,:/XA?*C.*(^[SE`,:/XA?*C.*`^[SE`,:/XA?*C.)X^[SE`,:/
MXA?*C.)P^[SE`,:/XA?*C.)H^[SE`,:/XA?*C.)@^[SE`,:/XA?*C.)8^[SE
M`,:/XA?*C.)0^[SE`,:/XA?*C.)(^[SE`,:/XA?*C.)`^[SE`,:/XA?*C.(X
M^[SE`,:/XA?*C.(P^[SE`,:/XA?*C.(H^[SE`!"@X0(`H.$'T,WC-```ZD@@
MG^5($)_E`B"/X$0`G^4!,)+G``"/X`,`4.$>_R\A<$`MZ0!`H.,`4*#A`6!#
MX@!@1N`F8:#A!#"5Y#/_+^$&`%3A`4"$XOK__QIP@+WH\'D!`!@!``#L>`$`
M\$$MZ6`PG^5@$)_E8""?Y0,PC^`!4)/G`G"3YP<`5>'P@;TH`7!'X@5P1^``
M0*#C"%"%XJ=QH.$'``#J"&`5Y0A0A>(`,);E,_\OX0<`5.$``(;E`4"$XO"!
MO0@$,%7EH`!3X_3__PHG___KC'D!`#P!```@`0``@$`MZ6R!G^4`4%'B"("/
MX`C03>)+```*7"&?Y5PQG^4"()CG`%""Y0-@F.<(()7E`#"5Y0`@AN4`()/E
M``!2XSH```HX$9_E`1"8YP`@@>4`()/E`##2Y0``4^,%```*`2""XB\`4^,`
M(($%`3#2Y```4^/Z__\:``!0XP````KW_O_KDO__Z_@PG^4#,)CG``!3XS4`
M``KL,)_E['"?Y0.0F.<'<(_@"0!7X0&023('D$DP`$"@,RF1H#$$```J!#"7
MY#/_+^$)`%3A`4"$XOK__QJX`)_EN'"?Y0``C^#?_O_KL#"?Y0=PC^`#@)CG
M"`!7X0&`2#('@$@P`$"@,RB!H#$$```J!#"7Y#/_+^$$`%CA`4"$XOK__QH`
M();E`!"5Y00`E>5G"P#KL?[_ZTPPG^5D()_E`S"8YP(@C^``((/ER___ZA/`
MH.-0,)_E`B"@XP0`H.,`$*#C`S"/X`#`C>7Z_O_K`0"@X]?^_^N$___KQ___
MZAAY`0!D`0``.`$``&P!``!<`0``*`$``(1W`0!(_O__0'<!`$0!``#0>0$`
M&#```,PPG^7P1RWI`)!0X@,PC^`K```*O""?Y0(PD^<`@)/E``!8XR@```H`
M4-GE`7"@X0``5>,]`%43`5"@$P!0H`,1```:`$"8Y0``5.,,```*"&"@X00`
MH.$%(*#A"1"@X9+^_^L``%#C`@``&@4PU.<]`%/C"P``"@1`MN4``%3C\___
M&@0`H.'PA[WH"5"@X0$P]>4``%/C/0!3$_O__QH)4$7@YO__Z@A@1N`!4(7B
M1F&@X05`A.`$`*#A`&"'Y?"'O>@)0*#A[?__Z@A`H.'K___J<'<!`#@!``#P
M0RWI7"&?Y5PQG^4"((_@`S"2YZ303>(`4%#B`#"3Y9PPC>4`,*#C`@``"@`P
MU>4``%/C"@``&C`AG^4H,9_E`B"/X`,PDN<`()/EG#"=Y0(@,^``,*#C00``
M&J30C>+P@[WHEO[_ZP!`4.+Q__\*#7"@X?B`G^4(@(_@!`"@X0'__^L``%#C
M)P``"@TPT.4-8(#B+@!3XP(``!H!,-;E``!3X_3__PH-,-#E+@!3XR(```H%
M`*#AY_[_ZP"0H.$&`*#AY/[_ZP``B>`"`(#BY_[_ZP8PH.$`8*#A!2"@X0@0
MH.'3_O_K!Q"@X08`H.%2_O_K`0!PXP8`H.$#```*"#"=Y0\Z`^(!"5/C$@``
M"D'^_^L&`*#A-O[_ZP0`H.'9_O_K``!0X]?__QH$`*#A7?[_ZP4`H.$9_O_K
MO?__Z@$PUN4N`%/CV?__&@(PUN4``%/CR/__"M7__^JG___KZ___ZD3^_^N4
M=@$`0`$``&!V`0#$+@``$$`MZ8P@G^6,,)_E`B"/X*#03>(#,)+G#1"@X0`P
MD^6<,(WE`#"@XP!`H.$?_O_K``!0XP``H!,$```:"#"=Y0\Z`^(*"E/C`0E3
M$PH```I(()_E0#"?Y0(@C^`#,)+G`""3Y9PPG>4"(#/@`#"@XP<``!J@T(WB
M$("]Z`(0H.,$`*#A;/[_ZQ`/;^&@`J#A[O__ZAK^_^L<=0$`0`$``-!T`0`0
M0"WI],"?Y?0PG^4!VTWB"-!-X@S`C^`#,)SG!$"-X@`0H.$!*Z#C!`"@X0`P
MD^4$-(WE`#"@X]7]_^L!`$#B!`!0X0<``)H`(*#C`@``Z@0`4.$!(,#E`@``
M"@$P4.0O`%/C^?__"B\0H.,$`*#AUOW_ZP``4.,0```*!`!0X0`PH(,`,,"%
M!`"@X5#^_^MP()_E:#"?Y0(@C^`#,)+G`""3Y00TG>4"(#/@`#"@XQ$``!H!
MVXWB"-"-XA"`O>A$()_E.#"?Y0(@C^`#,)+G`""3Y00TG>4"(#/@`#"@XP4`
M`!HD`)_E``"/X`';C>((T(WB$$"]Z#7^_^K7_?_K<'0!`$`!``#L<P$`O',!
M``@L``#P0"WI`&"@X?@`G^7X,)_E``"/X`';3>(#,)#G#-!-XN@`G^4$<(WB
M`5"@X>`@G^4'$*#A``"/X``PD^4$-(WE`#"@X\_]_^L`P%#B%P``V@%`3.(!
M.X3B"#"#X@,PC>`$-%/E``!3XR,``!H``%3C#@``"@0@H.$O$*#C!P"@X07^
M_^L``%#C"```"H0`G^4``(_@)_[_ZP0PH.$'(*#A!A"@X0``D.4'_O_K!@``
MZF0`G^4``(_@'O[_ZP4@H.$&$*#A``"0Y:+]_^M,()_E-#"?Y0(@C^`#,)+G
M`""3Y00TG>4"(#/@`#"@XP0``!H!VXWB#-"-XO"`O>@,0*#AV___ZI#]_^M@
M<P$`0`$``.`K``#_`P``$'0!`.QS`0"<<@$`\$<MZ0%`H.$4(I_E%#*?Y0(@
MC^`#,)+G"-!-X@`PD^4$,(WE`#"@XP`PT>4`4*#A/0!3XP%`@0($`*#A\?W_
MZPT0H.$`8*#A!0"@X9_^_^O4<9_E`)!0X@=PC^!!```*Z/W_ZP``5N$X``":
MO#&?Y0"`G>4#<)?G"(&@X0`PU>4``%/C/0!3$P$PH!,`,*`#!0``"@4PH.$!
M(//E``!2XST`4A/[__\:!3!#X`(`AN(#`(#@`&"7Y=C]_^L``%#C"`"&YQ8`
M``H%`*#A`#"7Y0`@G>4"$9/G`3#0Y```4^,]`%,3`##!Y08```H!(('B`3#0
MY`(0H.$``%/C/0!3$P$PPN3Y__\:/3"@XP$@H.$`,,'E`3#4Y```4^,!,.+E
M^___&@@AG^7X,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C-0``&@C0C>+P
MA[WH`9!)X@$PU.0``%/C`3#IY?O__QKN___JP#"?Y0-PE^<`@)?E`#"8Y0``
M4^,D```*"#"@X00@L^4)$*#A``!2XP&0B>+Z__\:`Q"!X@$1H.&0,)_E`S"/
MX``@D^4``%+C#P``&@$@H.,!`*#A`""#Y9;]_^L`H%#BU?__"@@0H.$)@:#A
M"""@X=;\_^L`H(?E`""@XP$PB>(#(8KG`)"-Y:'__^H(`*#AR_S_ZP``4.,`
MH*#A``"'Y<7__PH)@:#A\O__Z@.0H.$($*#CW___Z@#]_^L\<@$`0`$``/1Q
M`0`X`0``('$!`,!R`0!P0"WI/""?Y3P`G^4\,)_E`B"/X```C^`#8)+G;?W_
MZRQ0G^4L0)_E!5"/X`1`C^`%,*#A!B"@X000H.%P0+WH``"0Y1C]_^H`<`$`
M+'$!`"0!``#X:```G"@``#!`+>E8`)_E%-!-X@``C^!9_?_K`$"@X0``D.7@
M___K`,"@XSQ0G^4`$)3E.""?Y050C^`T,)_E`B"5YPP0C>4L$)_E`S"/X`P`
MG>4!$(_@`#"-Y03`C>47_?_K%-"-XC"`O>C8<`$`A&\!`'`!```$*P``/"@`
M````H.,>_R_A\$\MZ3PBG^4\,I_E2]Y-X@S03>("((_@`%"@X2P"G^4#,)+G
M&&"-X@%PH.$``(_@!!!&X@`PD^6T-(WE`#"@X]S]_^LO$*#C`$"@X04`H.&!
M_/_K``!0XQ````KP`9_E!1"@X0``C^`>___K!0"@X>`AG^70,9_E`B"/X`,P
MDN<`()/EM#2=Y0(@,^``,*#C:P``&DO>C>(,T(WB\(^]Z`<`H.'V_/_KK!&?
MY0$0C^"?_/_K`*!0XN?__PH`,-KEF)&?Y9B!G^68<9_E``!3XPF0C^`(@(_@
M!W"/X#T```H``%3C!```"@H0H.$$`*#A!_W_ZP``4.,M```*"@"@X?K\_^L`
M,*#A`2!`X@(@BN`"`%KA`+"@X0,PBC```*`S`1"*,@,``#H(``#J`P!1X0``
MP^4"```*`2!SY2\`4N/Y__\*"@"@X>C\_^L`L*#A!0"@X>7\_^L+`(#@`0"`
MX@$+4..\__\J_!"?Y;2PC>(!$(_@!S"@X0$KH.,B`(WI"P"@X0`0H.,`H(WE
M@/S_ZP80H.$+`*#A3?S_ZP``4.,#```:(#"=Y0\Z`^(""5/C%```"K00G^4`
M`*#C`1"/X%O\_^L`H%#BH___"@`PVN4``%/CP?__&@``5.,5```*`##4Y2X`
M4^,"```*`;"@XPF@H.'5___J`3#4Y0``4^/K__\*^/__Z@$0H.,+`*#AC/S_
MZP``4./E__\:4`"?Y0L0H.$``(_@KO[_ZPL`H.&3_/_KC?__Z@&PH.,(H*#A
MPO__ZC'\_^L@;P$`0`$``/0G``#()P``O&X!`)`G``#0)@``S"8``&@G```L
M)@``@"8```@F```00"WI+Q"@XP!`H.']^__K``!0XP%`@!($`*#A$$"]Z'G\
M_^H00"WI`$!0X@D```H`,-3E``!3XP8```J-_/_K`0"`X@$+4.,&``"*!`"@
MX1!`O>CW_?_J$`"?Y1!`O>@``(_@:/S_Z@``H.,0@+WHR"0``'!`+>G$))_E
MQ#2?Y0(@C^#`5)_E`S"2Y[QDG^4(T$WB!5"/X``PD^4$,(WE`#"@XP9@C^`-
M0*#A!!"@X08`H.$A_?_K``!0XPX```J,-)_E`!"=Y0,PE><`()/E`3&"X`0`
MD^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^I49)_E!F"/
MX`00H.$&`*#A"_W_ZP``4.,.```*-#2?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E
M``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J`&2?Y09@C^`$
M$*#A!@"@X?7\_^L``%#C#@``"MPSG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``
M4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZJQCG^4&8(_@!!"@
MX08`H.'?_/_K``!0XPX```J$,Y_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C
M`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^I88Y_E!F"/X`00H.$&
M`*#AR?S_ZP``4.,.```*+#.?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!
M@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J!&.?Y09@C^`$$*#A!@"@
MX;/\_^L``%#C#@``"M0RG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G
M\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZK!BG^4&8(_@!!"@X08`H.&=
M_/_K``!0XPX```I\,I_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'_
M_PH$,(/B!""3Y0``4N,$((/D^___&NO__^I<8I_E!F"/X`00H.$&`*#AA_S_
MZP``4.,.```*)#*?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*
M!#"#X@0@D^4``%+C!""#Y/O__QKK___J"&*?Y09@C^`$$*#A!@"@X7'\_^L`
M`%#C#@``"LPQG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P
M@^($()/E``!2XP0@@^3[__\:Z___ZK1AG^4&8(_@!!"@X08`H.%;_/_K``!0
MXPX```IT,9_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B
M!""3Y0``4N,$((/D^___&NO__^I@89_E!F"/X`00H.$&`*#A1?S_ZP``4.,.
M```*'#&?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@
MD^4``%+C!""#Y/O__QKK___J#`&?Y000H.$``(_@,/S_ZP`04.("```*^`"?
MY0``C^!W_?_K\`"?Y000H.$``(_@)_S_ZP`04.("```*W`"?Y0``C^!N_?_K
MU`"?Y000H.$``(_@'OS_ZP`04.(2```*P`"?Y0``C^!E_?_KN""?Y60PG^4"
M((_@`S"2YP`@D^4$,)WE`B`SX``PH.,0```:F!"?Y9@`G^4!$(_@``"/X`C0
MC>)P0+WH5?W_ZH0`G^4$$*#A``"/X`7\_^L`$%#BZ?__"G``G^4``(_@3/W_
MZ^7__^K4^O_K/&P!`$`!```H;`$`+"4``#@!``#<)```C"0``$`D``#P(P``
MJ",``/`B```$(P``N"(``&PB``"<(0``Q"$``)@A``"T(0``@"```*0A``#8
M(```W&<!`.0B``#P(```4"$``.`@```$X"WE>""?Y7@PG^4"((_@=`"?Y0S0
M3>(#,)+G#1"@X0``C^``,)/E!#"-Y0`PH./7^__K``!0XP4```H``-#E``!0
MXS``4!,!`*`#``"@$P$`(.(T()_E*#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@
M`#"@XP$``!H,T(WB!/"=Y)GZ_^L$9P$`0`$``$@@``"T9@$`#P`MZ03@+>5$
M()_E1#"?Y0(@C^`#,)+G#-!-X@`PD^4$,(WE`#"@XRPPG^44((WB*`"?Y0,P
MC^``((WE``"3YQ`0G>6P`(#BV?K_Z_\`H.,^^O_K;&8!`$`!``!(9@$`:`$`
M``(0H./P3RWI?$&?Y7SAG^4!V$WB'-!-X@1`C^`.X)3G`<B-X@`@H.,`,*#C
M`.">Y13@C.4`X*#C`!"-Y13`C.(`D*#AT/K_ZP%@4.(`$,'BP2^@X<$_)N`"
M,%/@<S#_Y@(P(^`",%/@`B#"X`-@5N`"@,'@``!8XSP``+H0L9_E$'&?Y1"A
MG^4+L(_@#%"-X@=PC^``$*#C!B"@X0@PH.$)`*#A`!"-Y;?Z_^L!`''C`0!P
M`S````H*(*#A!1"@X0D`H.%N^O_K`0!PXQ\```H'`%#C(```F@@`0.(`0)7@
M`P``.AP``.H!0$3B!0!4X1D``#H((*#C!Q"@X00`H.&5^O_K``!0X_;__QH%
M$$3@!@"1X,$?J."`P)_E;""?Y0S`C^`!.(WB`B"<YQ0P@^(`P)+E`""3Y0S`
M,N``(*#C$```&@'8C>(<T(WB\(^]Z$P`G^4``(_@C___ZP%H5N(`@,CB`0!X
MXP$(=@/(__\:``#@XP`0H.'F___J"P"@X87__^O+___J&?K_ZP!F`0!``0``
M6!\```1G`0`(``$`^&0!`)P>```00"WI@OK_ZWOZ_^L``%#C``"0%1"`O>CP
M0"WI+"&?Y2QAG^4L,9_E`B"/X!303>(#,)+G!F"/X`!0H.$&`*#A"!"-X@`P
MD^4,,(WE`#"@XR?[_^L`0%#B`@``"@`PU.4``%/C#@``&NP@G^7D,)_E`B"/
MX`,PDN<`()/E##"=Y0(@,^``,*#C+P``&@40H.'(`)_E``"/X!30C>+P0+WH
M7_S_Z@40H.&W^?_K``!0XPH```JH()_EF#"?Y0(@C^`#,)+G`""3Y0PPG>4"
M(#/@`#"@XQP``!H4T(WB\("]Z`4`H.%0^O_K`'"@X00`H.%-^O_K``"'X`(`
M@.)0^O_K8#"?Y6`0G^4%(*#A`$"-Y0,PC^`!$(_@`$"@X3GZ_^M(()_E+#"?
MY0(@C^`#,)+G`""3Y0PPG>4"(#/@`#"@XP00H`$&`*`!TO__"K[Y_^M(9`$`
M(!X``$`!````9`$`P!T``+1C`0!H'```:!P``$AC`0#P3RWI1!:?Y43&G^5$
M)I_E`1"/X`(@D>=)WTWB#,"/X`PPC.(84(SB('"-XCC@C>(`()+E'"&-Y0`@
MH.,`D*#A!P"3Z`<`A^@/`+7H#P"NZ`,`E>@PP(SB+$"-X@,`CN@'`)SH!P"$
MZ.P%G^4<8(WB!A"@X0``C^#`^O_KW*6?Y0!04.(*H(_@`@``"@`PU>4``%/C
M#0$`&GO__^L`4%#B\0``"@4`H.$"^O_K@`"@X0$`@.(%^O_K`"#5Y0"`H.$`
M`%+C"0``"@A`H.&0M9_E"["/X`0`H.$+$*#A[/G_ZP$@]>4"0(3B``!2X_C_
M_QIP!9_E/%"-X@``C^`"``#J!`"5Y```4.,-```*!A"@X9KZ_^L`0%#B^/__
M"@`PU.4``%/C]?__"BG[_^L``%#C\O__"@0`H.'#^?_K`$!0XA,``!H`4*#C
M$CZ-X@4Q@^``01/E``!4XPP```H!L(7B"[&'X``PU.4``%/C!P``"@0`H.$6
M^__K``!0XP%0A>(W```:!$";Y```5./T__\:`$"@XP0`H.'&^?_K`%"@X0@`
MH.'#^?_K`%"%X`%;A>($4(7B!0"@X<3Y_^L`<*#AI#2?Y:04G^4#,(_@`#"-
MY9PTG^4$(*#A`S"/X`$0C^`$@(WEJOG_ZP<=H.,'`*#A>OG_ZP$`<..'```*
M!P"@X5`0C>(>^?_K`$!0XAD```I@))_E8!2?Y0(`FN<',*#A`""9Y0$0C^"P
M`(#B(/G_ZP!0H.-$))_E&#2?Y0(@C^`#,)+G`""3Y1PQG>4"(#/@`#"@X_P`
M`!H%`*#A2=^-XO"/O>@$`*#A=_G_ZP!`4.*T__\*QO__ZE@PG>4/.@/B`0E3
MX^'__QIL@)WE@_G_ZP``6.'=__\:6#"=Y8,[H.&C.Z#A!PU3X]C__QH%`*#A
MAOG_ZP!0H.'$`Y_E!A"@X0``C^`M^O_K`!!0XI0```H``)GE._S_ZP"`4.*0
M```*"`"@X7/Y_^L#`%#C`&"@X0P``)J,$Y_E!`!`X@``B.`!$(_@=/G_ZP``
M4.,%```:!`!6X[T```H&8(C@!3!6Y2\`4^.Y```*+_[_ZP!@4.($```:"`"@
MX080H.%.^?_K`(!0XG@``!H\$Y_E/`.?Y0$0C^```(_@5/O_ZR[Y_^L`P*#A
M*#.?Y2@3G^4#,(_@!#"-Y2`SG^4@DY_E((.?Y2!CG^4'(*#A!0"@X0,PC^`!
M$(_@`,"-Y0F0C^`(@(_@!F"/X#KY_^L-``#J`OG_ZP`PD.41`%/C#@``&A;Y
M_^L`P*#A`4"$X@DPH.$'(*#A"!"@X04`H.%0`(WI`,"-Y2OY_^L'':#C!0"@
MX?OX_^L!`'#C[/__"@<`H.&4^/_KI`*?Y040H.$``(_@)_O_ZP4`H.&B_O_K
MA?__ZN;X_^L`,)#E$0!3XW/__PH`()GE`%"@XQ0@C>7?^/_K`,"@X3`2G^4`
MP)SE`0":YUP2G^4',*#A%""=Y0$0C^``P(WEL`"`XI+X_^MQ___J!;"@X1(^
MC>(+,8/@]``3Y0``4.,@```*`8"+X@A1A.`&$*#ANOG_ZP`P4.((L*#A`@``
M"@`PT^4``%/C!```&@0`E>0``%#C$P``"@&`B.+R___JX?C_ZP!04.+H__\*
M]/[_ZG/^_^O8(9_E>#&?Y0(@C^`#,)+G`""3Y1PQG>4"(#/@`#"@XU0``!H%
M`*#A2=^-XO!/O>C0^/_J#0"@X^_X_^N@49_E4R"@XP"`H.$%4(_@Z/[_Z@"`
MF>5L___J[/W_ZP"@4>(`D*#A@O__N@H@4.(`,,KB`&"-Y0@`H.'H8(WBQOC_
MZP8@H.,&$*#A"`"@X8#X_^L&`%#C`@``"D@!G^4``(_@P?W_ZT`QG^7H()WE
M`P!2X6___QJT(-;A,#&?Y0,`4N%K__\:`!"@XS(@6>(`,,KB"`"@X0`0C>7P
M0(WBKOC_ZR@@H.,(`*#A!!"@X6CX_^LH`%#C`@``"O0`G^4``(_@J?W_ZP#`
MH./H()_EZ#"?Y>@0G^4"((_@!""-Y04`H.$'(*#A`$"-Y0,PC^`!$(_@&,'-
MY:'X_^MY___J!&"9Y0``5N-"__\*!@"@X:3X_^L#`%#C/O__FJ00G^4$`$#B
M``"&X`$0C^"F^/_K``!0XP:`H`$V___J(?C_Z^QB`0!<9`$`0`$``'0;``!X
M8@$`*!P``'0:``!$&P``)!L``(P9``!H`0``+!L``,!@`0#D&@``K!H``-@:
M````&0``)!L``$@:``#8%P``S!<``$P:``#P&@``X!<``+P8```@7@$`U!<`
M`$P8````0T%#2$4``.P7``"H&```:!4``,@7``!\%P``\$`MZ4PBG^5,,I_E
M`B"/X$@"G^4#,)+G#-!-X@``C^``,)/E!#"-Y0`PH.-M^/_K`#"@X0U@H.$`
M,)/E(`*?Y60@T^4&$*#A``"/X&4@P^43^?_K``!0XP(```H`,-#E,0!3XV,`
M``K:^__K]`&?Y?1!G^4``(_@6OC_ZP1`C^`$$*#A`S"@XP$@H.,`4*#A``"0
MY?;W_^L`0%#B"@``"@PPE.7$(9_E`!"3Y0``E>4"((_@T_?_ZPPPE.4`$)/E
M"#"1Y0$%$^-6```:H`&?Y:!!G^4``(_@0OC_ZP1`C^`$$*#A`S"@XP$@H.,`
M4*#A``"0Y=[W_^L`0%#B"0``"G0!G^4&$*#A``"/X.3X_^L`(%#B.P``"@PP
ME.4``)7E`!"3Y;?W_^M0`9_E4'&?Y0``C^`K^/_K2!&?Y0!0D.4!(*#C`$"@
MX0$0C^`%`*#AT_?_ZS`AG^4`$*#A`B"/X`4`H.&G]__K`""@XP`PE.48`9_E
M!A"@X0``C^!E(,/EQ_C_ZP=PC^```%#C"`"'Y1````H'':#CV??_ZP$P@.(1
M`%#C`0!3$R(``(K@()_EI#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XQ@`
M`!H,T(WB\("]Z`0`E^70_?_K``!0XP@`A^7I__\:I`"?Y0``C^"M]__K`3#0
MY0``4^.9__\*E___ZHPPG^4,()3E`S"/X`0PD^4``)+E`!"3Y:+Y_^N____J
M``"5Y;'W_^NE___J</?_ZV`@G^4`,*#A7`"?Y0(@C^`&`)+I``"/X``0D>65
M]__K%%P!`$`!```T70$`%!4``-Q<`0"D%@``=!8``'Q<`0!0%@``$!0``"!<
M`0"T7`$`Z!4``.P5``"4$P``;%H!`&`5```H7`$`]%L!`"@5```00"WI`$"@
MX9;\_^L``%3C``!0$Q"`O0@`,-3E``!3XQ"`O0@$`*#A+/O_ZR+[_^L<$)_E
M!""@XP$0C^`:]__K``!0XQ"`O1@$`*#A$$"]Z*#X_^I0$P``\$\MZ5/?3>(-
M(*#A*!N?Y2@[G^4!$(_@`S"1YP+`H.$`,)/E1#&-Y0`PH.,<$(#B7."`X@0P
MD>0S/[_F`0!>X00PK.7Z__\:`4R-X@(0H.$X,)'E)."1Y0P0D>4$P++E#C`C
MX`$P(^`,,"/@XS^@X00`4N%`,(+E\___&L`ZG^4(()WE#&"0Y000G>404)#E
M`R""X`!0D.D`0)#E!G""X`,0@>`&("[@!1"!X`P@`N`&("+@#("=Y>0=@>`"
M$('@;"$NX&21H.$#@(C@!"`"X`ZPB.`.("+@;($IX`<@@N`!@`C@$'"=Y6R!
M*.`#<(?@"X"(X!2PG>7A+8+@;*&'X&%Q*>#BC8C@`G`'X`.PB^!B(:#A";"+
MX`EP)^!AD2+@")`)X`IPA^!AD2G@&*"=Y>A]A^`+D(G@:+$BX`.@BN`'L`O@
MYYV)X&&ABN!G$:#A`G`KX`IPA^`<H)WE:+$AX`.@BN`"((K@(*"=Y0FP"^`#
MH(K@Z7V'X&BABN!H@2O@:;$AX`*`B.`'L`O@YXV(X&<AH.$!<"O@"G"'X"2@
MG>5IL2+@`Z"*X`&@BN`H$)WE"+`+X`,0@>!I$8'@:9$KX.A]A^`*D(G@:*$B
MX`>@"N`"H"K@`1"*X"R@G>7GG8G@`Z"*X&=QH.$"H(K@,""=Y6BQ)^`)L`O@
M`R""X&@A@N!H@2O@Z1V!X`J`B.!IH2?@`:`*X`>@*N`"((K@-*"=Y>&-B.`#
MH(K@81&@X0>PBN`X<)WE::$AX`-PA^`(H`K@Z"V"X&EQA^!IH2K@:)$AX`*0
M">`!D"G@!W")X#R0G>4+H(K@`Y")X.*MBN`!L(G@8B&@X4`0G>5HD2+@`Q"!
MX`J0">#J?8?@:!&!X&B1*>!J@2+@!X`(X`*`*.`!@(C@1!"=Y0N0B>`#$('@
MYYV)X`*P@>!G<:#A2""=Y6H1)^`#((+@"1`!X.F-B.!J(8+@:A$AX&FA)^`(
MH`K@!Z`JX`(@BN!,H)WE"Q"!X`.@BN`'<(K@4*"=Y>@=@>!H@:#A`S"*X&FA
M*.`!H`K@::$JX.$M@N`'H(K@87$HX`)P!^!I,8/@"'`GX%BPG>4#<(?@$#B?
MY520G>7BK8K@`["+X&(AH.$#D(G@8;&+X&$1(N`*$"'@"(")X.I]A^`!@(C@
MYYV(X%R`G>4#@(C@`H"(X&HA(N`'("+@`B"+X.D=@N!@()WE9W&@X0,@@N!J
M(8+@:J$GX`F@*N`*@(C@9*"=Y>&-B.`#H(K@!Z"*X&EQ)^`!<"?@!W""X&@@
MG>5A$:#A`R""X&DA@N!ID2'@")`IX`F0BN!LH)WEZ'V'X`.@BN`!H(K@:!$A
MX`<0(>`!$(+@<""=Y>>=B>`#((+@9W&@X6@A@N!H@2?@"8`HX`B`BN!TH)WE
MZ1V!X`.@BN`'H(K@:7$GX`%P)^`'<(+@>""=Y>&-B.`#((+@81&@X6DA@N!I
MD2'@")`IX`F0BN!\H)WEZ'V'X`.@BN`!H(K@:!$AX`<0(>`!$(+@@""=Y>>=
MB>`#((+@9W&@X6@A@N!H@2?@"8`HX`B`BN"$H)WEZ1V!X`.@BN`'H(K@:7$G
MX&&QH.$!<"?@X8V(X`=P@N!I$2O@B""=Y0@0(>#H?8?@`1"*X`,@@N!HH2O@
M:2&"X`>@*N`*H(+@D""=Y>>=@>",$)WE9W&@X0,@@N!H(8+@`Q"!X&B!)^`+
M$('@"8`HX`B`@>"4$)WEZ:V*X`,0@>`'$('@:7$GX`IP)^`'<(+@F""=Y>J-
MB.`#((+@:J&@X6DA@N!ID2K@")`IX`D0@>"<D)WEZ'V'X`.0B>`*D(G@:*$J
MX`>@*N`*((+@H*"=Y><=@>`#,(K@9W&@X6@Q@^!H@2?@`8`HX.$M@N`(@(G@
M89$GX`*0*>#BC8C@"3"#X.B=@^"DL)WEL#6?Y:B@G>5B(:#A`["+X`>PB^`#
MH(K@87&"X6&ABN`(<`?@81$"X`$0A^$+$('@:+&"X>D=@>!I<:#A";`+X&B1
M`N`)D(OAK+"=Y0J0B>"PH)WE`["+X`*PB^`#H(K@:"&'X6BABN`!(`+@:($'
MX.&=B>`(((+A88&'X0L@@N`)@`C@8;$'X`N`B.&TL)WEZ2V"X`.PB^`'L(O@
MN'"=Y6F1H.$*@(C@`W"'X&&AB>$"H`K@87&'X&$1">#BC8C@`1"*X6*AB>$+
M$('@"*`*X&*Q">`+H(KAO+"=Y>@=@>`#L(O@";"+X,"0G>5H@:#A!W"*X`.0
MB>!BH8CA`:`*X&*1B>!B(0C@X7V'X`(@BN%AH8CA"R""X`>@"N!AL0C@"Z"*
MX<2PG>7G+8+@`["+X`BPB^#(@)WE9W&@X0F0BN`#@(C@8:&'X0*@"N!A@8C@
M81$'X.*=B>`!$(KA8J&'X0L0@>`)H`K@8K$'X`N@BN',L)WEZ1V!X`.PB^`'
ML(O@T'"=Y6F1H.$(@(K@`W"'X&*AB>$!H`K@8G&'X&(A">#AC8C@`B"*X6&A
MB>$+((+@"*`*X&&Q">`+H(KAU+"=Y>@M@N`#L(O@";"+X-B0G>5H@:#A!W"*
MX`.0B>!AH8CA`J`*X&&1B>!A$0C@XGV'X`$0BN%BH8CA"Q"!X`>@"N!BL0C@
M"Z"*X=RPG>4)D(K@X*"=Y><=@>`#L(O@9W&@X0BPB^`#H(K@8H&'X6*ABN`!
M@`C@8B$'X.&=B>`"@(CA82&'X0N`B.`)(`+@8;$'X`L@@N'DL)WE"B""X.B@
MG>7IC8C@`["+X&F1H.$'L(O@`Z"*X&%QB>%AH8K@"'`'X&$1">#H+8+@`7"'
MX6@1B>$+<(?@`A`!X&BQ">`+$('A"A"!X.R@G>7B?8?@`Z"*X`F0BN#PH)WE
M8B&@X0,PBN!HH8/@:#&"X0<P`^!H@0+@"("#X0F0B.#<,I_E]("=Y><=@>!G
ML8+A`X"(X`&P"^`"@(C@9R$"X`(@B^$*((+@^*"=Y>&=B>`#H(K@81&@X6>A
MBN!G<2'@"7`GX`>`B.#\<)WE`+&=Y0-PA^#I+8+@`7"'X&D1(>#BC8C@`A`A
MX`.PB^!B(:#A`1"*X&FQB^`$H9WE:9$BX`B0*>`)<(?@`Z"*X`B1G>7H'8'@
M`J"*X&@A(N#A?8?@`2`BX`.0B>!A$:#A:)&)X&B!(>`'@"C@"("*X`RAG>4"
M((O@`Z"*X.<M@N`!H(K@9Q$AX`(0(>`!$(G@$)&=Y>*-B.`#D(G@8B&@X6>1
MB>!G<2+@"'`GX`=PBN`4H9WEZ!V!X`.@BN`"H(K@:"$BX`$@(N`"((G@&)&=
MY>%]A^`#D(G@81&@X6B1B>!H@2'@!X`HX`B`BN`<H9WEYRV"X`.@BN`!H(K@
M9Q$AX`(0(>`!$(G@()&=Y>*-B.`#D(G@8B&@X6>1B>!G<2+@"'`GX`=PBN`D
MH9WEZ!V!X`.@BN`"H(K@:"$BX`$@(N`"((G@*)&=Y>%]A^`#D(G@81&@X6B1
MB>!H@2'@!X`HX`B`BN`LH9WEYRV"X`.@BN`!H(K@9Q$AX`(0(>`!$(G@,)&=
MY>*-B.`#D(G@8B&@X6>1B>!G<2+@"'`GX`=PBN`TH9WEZ!V!X`.@BN`"H(K@
M:"$BX`$@(N`"((G@.)&=Y>%]A^`#D(G@81&@X6B1B>!H@2'@!X`HX.<M@N`(
M@(K@XHV(X&AAAN`,8(#E/&&=Y0-@AN`!8(;@9Q$AX`(0(>`!$(G@Z!V!X&'A
MCN`(X(#E0.&=Y6(AH.$#,([@9^$BX`)0A>`$,(/@".`NX&@A(N`!("+@9S&#
MX`[@AN#A'8[@`C"#X.$]@^`!P(S@"!"`Z$0@G^4L,)_E`B"/X!!0@.4#,)+G
M`""3Y40QG>4"(#/@`#"@XP$``!I3WXWB\(^]Z&_T_^L,60$`0`$``)EY@EJA
MZ]ENW+P;C];!8LH03@$`<$`MZ6``H./C]/_K`""@XS#`G^4P$)_E,%"?Y3!`
MG^4PX)_E"%"`Y0Q`@.40X(#E`,"`Y000@.44((#E&""`Y5P@@.5P@+WH`2-%
M9XFKS>_^W+J8=E0R$/#ATL/P1RWI`I"@X0!0H.$4,)#E@B&@X0(PD^`8()#E
M%#"`Y5P`D.4!(((BJ2Z"X```4.,!0*#A&""%Y1R`A>(.```*0'!@X@<`6>$)
M<*"Q``"(X`<@H.$U]/_K7#"5Y0,PA^!``%/C7#"%Y?"'O1@%`*#A!Y!)X`=`
MA.#S_/_K/P!9XQT``-I`D$GB*6.@X0%PAN('<X3@"#"@X4#@A.(`P)3E!`"4
MY0@0E.4,()3E$$"$X@X`5.$`P(/E!`"#Y0@0@^4,((/E$#"#XO/__QH%`*#A
MW?S_ZP<`5.'M__\:!FUFX`:3B>`)(*#A!Q"@X0@`H.$.]/_K7)"%Y?"'O>@$
M<*#A]___ZG_`X./P02WI%#"1Y1A@D>4S?[_FHS&@X3\P`^(!((/B'("!XC@`
M4N,`4*#A`4"@X39OO^8#P,CG`@"(X#L``-H`$*#C0"!BXA7T_^L$`*#AO/S_
MZP@`H.$X(*#C`!"@XP_T_^L$`*#A]&7$X;7\_^L#,-3E!`"@X0`PQ>6R,-3A
M`3#%Y0`PE.4C-*#A`C#%Y0`PE.4#,,7E!S#4Y00PQ>6V,-3A!3#%Y00PE.4C
M-*#A!C#%Y00PE.4',,7E"S#4Y0@PQ>6Z,-3A"3#%Y0@PE.4C-*#A"C#%Y0@P
ME.4+,,7E#S#4Y0PPQ>6^,-3A#3#%Y0PPE.4C-*#A#C#%Y0PPE.4/,,7E$S#4
MY1`PQ>6R,=3A$3#%Y1`PE.4C-*#A$C#%Y1`PE.43,,7E\$&]Z*/S_^H`$*#C
M."!BXMGS_^O(___J$$`MZ5@PG^580)_E`S"/X"0@T^4$0(_@``!2XQ"`O1@!
M$*#C0""?Y200P^4",)3G``!3XP(```HP,)_E`P"?YW;S_^LH,)_E`S"4YP``
M4^,0@+T('`"?Y1!`O>@``(_@X_/_Z@Q-`0`42P$`'`$``&1,`0!4`0``8$4`
M`#P0G^4\,)_E`1"/X``@T>4#,(_@``!2XQ[_+Q$!`*#C)""?Y0``P>4",)/G
M``!3XQ[_+P$4`)_E!!"!X@``C^#5\__JE$P!`)Q*`0!8`0``!$4``/!`+>E,
MPI_E)-!-XD@RG^44`(WE$!"-Y0P@C>4,P(_@`S"<YQ`0C>(,((WB%`"-XBA"
MG^4`,)/E'#"-Y0`PH..B\__K&"*?Y01`C^`4,I_E`B"4YP,`E.<"$*#AI_/_
MZP0RG^4#,)3G`%#3Y0``5>-1```*]`&?Y0``C^#G\__K`""0Y11@G>5&,]+E
M!!"&X@,P@^,'`7'C`V"&XD8SPN5B``"*`0&@X7SS_^L`,*#A$!"=Y;AQG^4`
M`)'EM.&?Y0=PC^"!`(/HK,&?Y0[@C^"H(9_E!#".Y0P`E.<"((_@%%"=Y0P@
M@^4`()#E`0!5XP@@@^52``#:!`!!X@S`@^(%`8#@!."QY0$`4.$$X*SE^___
M&@-0A>(`P*#C8$&?Y6`1G^4$0(_@#`"4Y08@H.$`P(WE`1"/X`7!@^>$\__K
M``!0XRD```H\49_E&&"-X@50C^`,`)7E,O/_ZP!`H.$H`9_E!A"@X0``C^!:
M]/_K``!0XR````H4,9_E`S"/X`P`D^48\__K7_/_ZP0AG^7$,)_E`B"/X`,P
MDN<`()/E'#"=Y0(@,^``,*#C*```&@0`H.$DT(WB\("]Z"+S_^O4()_E``!0
MXP(@C^`,`(+E'0``"OCR_^O``)_E``"/X([S_^L`,)#EYE7#Y:#__^H,`)3E
M<?/_Z]+__^H(`)7E``!0XP$```JT^__KV?__ZHP`G^4&$*#A``"/X"[T_^L`
M`%#C"`"%Y=+__PKU___J<#"?Y7``G^4#$)3G``"/X"CS_^L$4*#CLO__Z@$`
MH..U\O_K]O+_ZSQ*`0!``0``$$H!`%`!``!@`0``+`$``!!+`0`P!0``I$L!
M`$P!```8!0``3$L!`&C9__\@2P$`/`(``/1*`0#$2`$`J$H!`*Q)`0`L`0``
M2`$``/0"``!P<U]S=')I;F=S(&UI<W-I;F<*`"]T;7`O````+@```%!!4E]4
M35!$25(``%1%35!$25(`5$U0`%5315(`````55-%4DY!344`````)7,O)7,`
M```O<')O8R]C=7)P<F]C+V5X90```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!005)?5$5-4`````!005)?
M4%)/1TY!344`````.@```"5S)7,E<P``4$523#5,24(`````4$523$Q)0@!0
M15),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/
M0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`````;'-E96L@9F%I;&5D`````')E860@
M9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S
M)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R
M971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@``
M``!S:&]R="!R96%D```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P``
M`"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`````,````%!!4CHZ4&%C
M:V5R.CI615)324].`````#$N,#8Q````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T`
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D
M8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*
M)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S
M7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@
M)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@
M;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@
M)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?
M<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO
M=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C
M(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA
M<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?
M1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD
M(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P
M;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A
M9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B
M7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C
M:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H
M92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,
M15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I
M.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U
M<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#
M86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD
M9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I
M;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@
M/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD
M(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P
M87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N
M7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF
M("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G
M02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L
M92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G
M86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS
M:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I
M<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#
M.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D
M;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O
M=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S
M92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7
M<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]
M"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB
M*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T
M>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X]
M(")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@
M)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L
M;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B
M.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@
M>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER
M.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L
M96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H
M+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C
M86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@
M*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[
M4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C
M86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H
M<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC`````$-!0TA%```!
M&P,[``$``!\```#<C/__&`$``#B-__\T`0``L(W__U0!``!8C___I`$``#20
M___(`0``K)'___0!``!0DO__&`(``&23__],`@``B)3__WP"``#$EO__K`(`
M`""7___0`@``F)?___`"``"@E___!`,``!B:__\\`P``/)K__UP#``",FO__
MA`,``,2?__^T`P``6*#__]0#``"\H/__^`,``&2B__\P!```?*+__T@$``#8
MH___@`0``+2J___(!```7*W___`$``"TK?__.`4```RY__]L!0``:+G__X@%
M``!LNO__K`4``*R[__^$`0``*+S__W`!``!\O/__$`4``!```````````7I2
M``)\#@$;#`T`&````!@```"\B___7`````!2#A"$!(4#A@*.`1P````T````
M_(O__W@`````0@X8A`:%!88$AP.(`HX!&````%0```!4C/__J`$```!"#@B'
M`HX!2`X0`!````!P````L+K__U0`````````'````(0````@NO__?`````!"
M#@B$`HX!;,[$#@`````@````I````*R-___<`````$0.((0(A0>&!H<%B`2)
M`XH"C@$H````R````&2.__]X`0```$(.'(0'A0:&!8<$B`.)`HX!2@[``60*
M#AQ""R````#T````L(___Z0`````0@X(A`*.`4@.J`%R"@X(0@L``#`````8
M`0``,)#__Q0!````0@X(A`*.`48.B`A"#I`(`E0*#@A""UH*#@A"SL0.`$(+
M```L````3`$``!"1__\D`0```$(.%(0%A02&`X<"C@%*#I0(1`Z@"`)L"@X4
M0@L````L````?`$```22__\\`@```$(.((0(A0>&!H<%B`2)`XH"C@%,#B@"
MF`H.($(+```@````K`$``!"4__]<`````$(.$(0$A0.&`HX!7L[&Q<0.```<
M````T`$``$B4__]X`````$(.#(0#A0*.`40.(&H.#!````#P`0``H)3__P@`
M````````-`````0"``"4E/__>`(```!"#B2$"84(A@>'!H@%B02*`XL"C@%&
M#M0)0@[@"0)$"@XD0@L````<````/`(``-26__\D`````$(."(0"C@%.SL0.
M`````"0```!<`@``V);__U``````0@X(A`*.`58*SL0.`$(+1`K.Q`X`1`LL
M````A`(```"7__\X!0```$(.$(0$A0.&`HX!3@X8`SX""@X00L[&Q<0.`$(+
M```<````M`(```B<__^4`````$(.!(X!2@X0<@H.!$(+`"````#4`@``?)S_
M_V0`````0@X0@`2!`X("@P%"#A2.!4H.(#0```#X`@``O)S__Z@!````1`XD
MA`F%"(8'AP:(!8D$B@.+`HX!1@ZD@`1"#L"`!`*:"@XD0@L`%````#`#```L
MGO__&`````!"#@B$`HX!-````$@#```LGO__7`$```!"#A2$!84$A@.'`HX!
M2@XH=@H.%$+.Q\;%Q`X`0@M<"@X40@L```!$````@`,``%"?___<!@```$(.
M)(0)A0B&!X<&B`6)!(H#BP*.`4P.R`(#(@$*#B1""P-.`0H.)$+.R\K)R,?&
MQ<0.`$(+```D````R`,``.2E__^H`@```$(.%(0%A02&`X<"C@%,#B`"W`H.
M%$(+'````/`#``!DJ/__6`````!"#@B$`HX!9L[$#@`````D````$`0``&2W
M__^P`@```$(.%(0%A02&`X<"C@%$#C@"U@H.%$(+,````#@$``!TJ/__6`L`
M``!"#B2$"84(A@>'!H@%B02*`XL"C@%"#O`"`Y8%"@XD0@L``!@```!L!```
MF+/__UP`````0@X0A`2%`X8"C@$@````B`0``-BS__\$`0```$(.((0(A0>&
M!H<%B`2)`XH"C@$L````K`0``+BT__]``0```$0.&(0&A06&!(<#B`*.`0*2
M"L[(Q\;%Q`X`0@L`````````)$8``*A%`````````0````$````!````RP(`
M``$```#5`@```0```.H"```!````"0,```\```"B!```&0```-R/`0`;````
M!````!H```#@CP$`'`````0````$````>`$```4```!T"P``!@```+0$```*
M````ZP0```L````0````%0`````````#````V)`!``(````8`@``%````!$`
M```7````>!$``!$```!@$```$@```!@!```3````"````/O__V\````(^O__
M;Q<`````````````````````````````````````````````````````````
MZ(\!````````````D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0
M$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3
M``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,`
M`)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``
MD!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0
M$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3
M``"0$P``D!,``.2/`0````````````````#<CP$``````````````````),!
M````````````X(\!``````"0D@$`````````````````Z(\!``````#$D@$`
M`````$R2`0"P-```P)(!`%"2`0`*4$%2+G!M"@`````\20``1$D```````!(
M20``3$D``%1)``#(20``7$D```````!@20``:$D```````!X3```1T-#.B`H
M3F5T0E-$(&YB,R`R,#(S,3`P."D@,3`N-2XP`$=#0SH@*&YB,R`R,#(S,3`P
M."D@,3`N-2XP`"1.971"4T0Z(&-R=#`N4RQV(#$N-"`R,#$X+S$Q+S(V(#$W
M.C,W.C0T(&IO97)G($5X<"`D`"1.971"4T0Z(&-R=#`M8V]M;6]N+F,L=B`Q
M+C(W(#(P,C(O,#8O,C$@,#8Z-3(Z,3<@<VMR;&P@17AP("0`)$YE=$)31#H@
M8W)T:2Y3+'8@,2XQ(#(P,3(O,#@O,3,@,#(Z-#DZ,#0@;6%T="!%>'`@)``D
M3F5T0E-$.B!C<G1B96=I;BYC+'8@,2XQ-R`R,#$X+S$R+S(X(#$X.C$W.C$Q
M(&-H<FES=&]S($5X<"`D`"1.971"4T0Z(&-R=&5N9"Y3+'8@,2XR(#(P,3,O
M,3(O,C`@,34Z,S4Z-#@@:F]E<F<@17AP("0`\<\"``````````````````@`
M```(````"`````@````;`````0``````````*BHJ($YO($QA8F5L(%!R;W9I
M9&5D("HJ*@``\<\"``````````````````@````(````"`````@````;````
M`0``````````*BHJ($YO($QA8F5L(%!R;W9I9&5D("HJ*@!!+@```&%E86)I
M``$D````!39+6@`&!P@!"0$*`A($%`$5`1<#&`$:`AP!(@%$`0`N<VAS=')T
M86(`+FEN=&5R<``N;F]T92YN971B<V0N:61E;G0`+FYO=&4N;F5T8G-D+G!A
M>``N;F]T92YN971B<V0N;6%R8V@`+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR
M96PN9'EN`"YR96PN<&QT`"YT97AT`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI
M8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+E-53E=?8W1F`"Y!4DTN871T
M<FEB=71E<P`N;F]I;FET````````````````````````````````````````
M````````````````"P````$````"````%`$``!0!```7```````````````!
M`````````!,````'`````@```"P!```L`0``&```````````````!```````
M```F````!P````(```!$`0``1`$``!0```````````````0`````````-P``
M``<````"````6`$``%@!```@```````````````$`````````$H````%````
M`@```'@!``!X`0``/`,```8`````````!`````0```!0````"P````(```"T
M!```M`0``,`&```'`````P````0````0````6`````,````"````=`L``'0+
M``#K!``````````````!`````````&`````)`````@```&`0``!@$```&`$`
M``8`````````!`````@```!I````"0```$(```!X$0``>!$``!@"```&````
M$P````0````(````;0````$````&````D!,``)`3```X`P`````````````$
M````!````'(````!````!@```,@6``#(%@``8#(`````````````!```````
M``!X`````0````(````H20``*$D``--```````````````0`````````@```
M``$````"````_(D``/R)```$`0`````````````$`````````(X````!````
M`@````"+````BP``W`0`````````````!`````````"8````#@````,```#<
MCP$`W(\```0```````````````0````$````I`````\````#````X(\!`."/
M```$```````````````$````!````+`````!`````P```.2/`0#DCP``!```
M````````````!`````````"U````!@````,```#HCP$`Z(\``/`````'````
M``````0````(````O@````$````#````V)`!`-B0``!T`0`````````````$
M````!````,,````!`````P```$R2`0!,D@``2```````````````!```````
M``#)````"`````,```#`D@$`E)(``$0``````````````$``````````S@``
M``$````P`````````)22```]```````````````!`````0```!\````!````
M,`````````#1D@``'P$``````````````0````$```#7`````0``````````
M````\),``(\```````````````0`````````X0````,``'```````````'^4
M```O```````````````!`````````/$````!`````0````23`0"NE```````
M`````````````0`````````!`````P``````````````KI0``/D`````````
,``````$`````````
